@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2018 The git2r contributors
+ *  Copyright (C) 2013-2020 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,7 +16,9 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include "git2r_arg.h"
+#include "git2r_deprecated.h"
 #include "git2r_diff.h"
 #include "git2r_error.h"
 #include "git2r_repository.h"
@@ -26,18 +28,49 @@
 #include <git2.h>
 #include <git2/sys/diff.h>
 
+#include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 
-int git2r_diff_count(git_diff *diff, size_t *num_files,
-		     size_t *max_hunks, size_t *max_lines);
-int git2r_diff_format_to_r(git_diff *diff, SEXP dest);
-int git2r_diff_print(git_diff *diff, SEXP filename, SEXP* buf_r);
-SEXP git2r_diff_index_to_wd(SEXP repo, SEXP filename);
-SEXP git2r_diff_head_to_index(SEXP repo, SEXP filename);
-SEXP git2r_diff_tree_to_wd(SEXP tree, SEXP filename);
-SEXP git2r_diff_tree_to_index(SEXP tree, SEXP filename);
-SEXP git2r_diff_tree_to_tree(SEXP tree1, SEXP tree2, SEXP filename);
+static int
+git2r_diff_count(
+    git_diff *diff, size_t *num_files,
+    size_t *max_hunks, size_t *max_lines);
+
+static int
+git2r_diff_format_to_r(
+    git_diff *diff,
+    SEXP dest);
+
+SEXP git2r_diff_index_to_wd(
+    SEXP repo,
+    SEXP filename,
+    git_diff_options *opts);
+
+SEXP
+git2r_diff_head_to_index(
+    SEXP repo,
+    SEXP filename,
+    git_diff_options *opts);
+
+SEXP
+git2r_diff_tree_to_wd(
+    SEXP tree,
+    SEXP filename,
+    git_diff_options *opts);
+
+SEXP
+git2r_diff_tree_to_index(
+    SEXP tree,
+    SEXP filename,
+    git_diff_options *opts);
+
+SEXP
+git2r_diff_tree_to_tree(
+    SEXP tree1,
+    SEXP tree2,
+    SEXP filename,
+    git_diff_options *opts);
 
 /**
  * Diff
@@ -67,45 +100,143 @@ SEXP git2r_diff_tree_to_tree(SEXP tree1, SEXP tree2, SEXP filename);
  * diff is written to a character vector. If filename is a character
  * vector of length one with non-NA value, the diff is written to a
  * file with name filename (the file is overwritten if it exists).
+ * @param context_lines The number of unchanged lines that define the
+ * boundary of a hunk (and to display before and after).
+ * @param interhunk_lines The maximum number of unchanged lines
+ * between hunk boundaries before the hunks will be merged into one.
+ * @param old_prefix The virtual "directory" prefix for old file
+ * names in hunk headers.
+ * @param new_prefix The virtual "directory" prefix for new file
+ * names in hunk headers.
+ * @param id_abbrev The abbreviation length to use when formatting
+ * object ids. Defaults to the value of 'core.abbrev' from the
+ * config, or 7 if NULL.
+ * @param path A character vector of paths / fnmatch patterns to
+ *     constrain diff. Default is NULL which include all paths.
+ * @param max_size A size (in bytes) above which a blob will be
+ * marked as binary automatically; pass a negative value to
+ * disable. Defaults to 512MB when max_size is NULL.
  * @return A S3 class git_diff object if filename equals R_NilValue. A
  * character vector with diff if filename has length 0. Oterwise NULL.
  */
-SEXP git2r_diff(SEXP repo, SEXP tree1, SEXP tree2, SEXP index, SEXP filename)
+SEXP attribute_hidden
+git2r_diff(
+    SEXP repo,
+    SEXP tree1,
+    SEXP tree2,
+    SEXP index,
+    SEXP filename,
+    SEXP context_lines,
+    SEXP interhunk_lines,
+    SEXP old_prefix,
+    SEXP new_prefix,
+    SEXP id_abbrev,
+    SEXP path,
+    SEXP max_size)
 {
     int c_index;
+    git_diff_options opts = GIT_DIFF_OPTIONS_INIT;
 
     if (git2r_arg_check_logical(index))
         git2r_error(__func__, NULL, "'index'", git2r_err_logical_arg);
-
     c_index = LOGICAL(index)[0];
 
+    if (git2r_arg_check_integer_gte_zero(context_lines))
+        git2r_error(__func__, NULL, "'context_lines'", git2r_err_integer_gte_zero_arg);
+    opts.context_lines = INTEGER(context_lines)[0];
+
+    if (git2r_arg_check_integer_gte_zero(interhunk_lines))
+        git2r_error(__func__, NULL, "'interhunk_lines'", git2r_err_integer_gte_zero_arg);
+    opts.interhunk_lines = INTEGER(interhunk_lines)[0];
+
+    if (git2r_arg_check_string(old_prefix))
+        git2r_error(__func__, NULL, "'old_prefix'", git2r_err_string_arg);
+    opts.old_prefix = CHAR(STRING_ELT(old_prefix, 0));
+
+    if (git2r_arg_check_string(new_prefix))
+        git2r_error(__func__, NULL, "'new_prefix'", git2r_err_string_arg);
+    opts.new_prefix = CHAR(STRING_ELT(new_prefix, 0));
+
+    if (!Rf_isNull(id_abbrev)) {
+        if (git2r_arg_check_integer_gte_zero(id_abbrev))
+            git2r_error(__func__, NULL, "'id_abbrev'",
+                        git2r_err_integer_gte_zero_arg);
+        opts.id_abbrev = INTEGER(id_abbrev)[0];
+    }
+
+    if (!Rf_isNull(path)) {
+        int error;
+
+        if (git2r_arg_check_string_vec(path))
+            git2r_error(__func__, NULL, "'path'", git2r_err_string_vec_arg);
+
+        error = git2r_copy_string_vec(&(opts.pathspec), path);
+        if (error || !opts.pathspec.count) {
+            free(opts.pathspec.strings);
+            git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
+        }
+    }
+
+    if (!Rf_isNull(max_size)) {
+        if (git2r_arg_check_integer(max_size))
+            git2r_error(__func__, NULL, "'max_size'", git2r_err_integer_arg);
+        opts.max_size = INTEGER(max_size)[0];
+    }
+
     if (Rf_isNull(tree1) && ! c_index) {
 	if (!Rf_isNull(tree2))
 	    git2r_error(__func__, NULL, git2r_err_diff_arg, NULL);
-	return git2r_diff_index_to_wd(repo, filename);
+	return git2r_diff_index_to_wd(repo, filename, &opts);
     }
 
     if (Rf_isNull(tree1) && c_index) {
 	if (!Rf_isNull(tree2))
 	    git2r_error(__func__, NULL, git2r_err_diff_arg, NULL);
-	return git2r_diff_head_to_index(repo, filename);
+	return git2r_diff_head_to_index(repo, filename, &opts);
     }
 
     if (!Rf_isNull(tree1) && Rf_isNull(tree2) && !c_index) {
 	if (!Rf_isNull(repo))
 	    git2r_error(__func__, NULL, git2r_err_diff_arg, NULL);
-	return git2r_diff_tree_to_wd(tree1, filename);
+	return git2r_diff_tree_to_wd(tree1, filename, &opts);
     }
 
     if (!Rf_isNull(tree1) && Rf_isNull(tree2) && c_index) {
 	if (!Rf_isNull(repo))
 	    git2r_error(__func__, NULL, git2r_err_diff_arg, NULL);
-	return git2r_diff_tree_to_index(tree1, filename);
+	return git2r_diff_tree_to_index(tree1, filename, &opts);
     }
 
     if (!Rf_isNull(repo))
         git2r_error(__func__, NULL, git2r_err_diff_arg, NULL);
-    return git2r_diff_tree_to_tree(tree1, tree2, filename);
+    return git2r_diff_tree_to_tree(tree1, tree2, filename, &opts);
+}
+
+static int
+git2r_diff_print_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    const git_diff_line *line,
+    void *payload)
+{
+    int error;
+
+    GIT2R_UNUSED(delta);
+    GIT2R_UNUSED(hunk);
+
+    if (line->origin == GIT_DIFF_LINE_CONTEXT ||
+        line->origin == GIT_DIFF_LINE_ADDITION ||
+        line->origin == GIT_DIFF_LINE_DELETION) {
+        while ((error = fputc(line->origin, (FILE *)payload)) == EINTR)
+            continue;
+        if (error == EOF)
+            return -1;
+    }
+
+    if (fwrite(line->content, line->content_len, 1, (FILE *)payload) != 1)
+        return -1;
+
+    return 0;
 }
 
 /**
@@ -119,10 +250,16 @@ SEXP git2r_diff(SEXP repo, SEXP tree1, SEXP tree2, SEXP index, SEXP filename)
  * diff is written to a character vector. If filename is a character
  * vector of length one with non-NA value, the diff is written to a
  * file with name filename (the file is overwritten if it exists).
+ * @param opts Structure describing options about how the diff
+ * should be executed.
  * @return A S3 class git_diff object if filename equals R_NilValue. A
  * character vector with diff if filename has length 0. Oterwise NULL.
  */
-SEXP git2r_diff_index_to_wd(SEXP repo, SEXP filename)
+SEXP attribute_hidden
+git2r_diff_index_to_wd(
+    SEXP repo,
+    SEXP filename,
+    git_diff_options *opts)
 {
     int error, nprotect = 0;
     git_repository *repository = NULL;
@@ -137,9 +274,9 @@ SEXP git2r_diff_index_to_wd(SEXP repo, SEXP filename)
         git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     error = git_diff_index_to_workdir(&diff,
-				    repository,
-				    /*index=*/ NULL,
-				    /*opts=*/ NULL);
+                                      repository,
+                                      /*index=*/ NULL,
+                                      opts);
 
     if (error)
 	goto cleanup;
@@ -164,14 +301,14 @@ SEXP git2r_diff_index_to_wd(SEXP repo, SEXP filename)
             nprotect++;
         }
 
-        git_buf_free(&buf);
+        GIT2R_BUF_DISPOSE(&buf);
     } else {
         FILE *fp = fopen(CHAR(STRING_ELT(filename, 0)), "w+");
 
         error = git_diff_print(
             diff,
             GIT_DIFF_FORMAT_PATCH,
-            git_diff_print_callback__to_file_handle,
+            git2r_diff_print_cb,
             fp);
 
         if (fp)
@@ -179,6 +316,7 @@ SEXP git2r_diff_index_to_wd(SEXP repo, SEXP filename)
     }
 
 cleanup:
+    free(opts->pathspec.strings);
     git_diff_free(diff);
     git_repository_free(repository);
 
@@ -186,7 +324,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return result;
 }
@@ -201,10 +339,16 @@ cleanup:
  * diff is written to a character vector. If filename is a character
  * vector of length one with non-NA value, the diff is written to a
  * file with name filename (the file is overwritten if it exists).
+ * @param opts Structure describing options about how the diff
+ * should be executed.
  * @return A S3 class git_diff object if filename equals R_NilValue. A
  * character vector with diff if filename has length 0. Oterwise NULL.
  */
-SEXP git2r_diff_head_to_index(SEXP repo, SEXP filename)
+SEXP attribute_hidden
+git2r_diff_head_to_index(
+    SEXP repo,
+    SEXP filename,
+    git_diff_options *opts)
 {
     int error, nprotect = 0;
     git_repository *repository = NULL;
@@ -233,7 +377,7 @@ SEXP git2r_diff_head_to_index(SEXP repo, SEXP filename)
         repository,
         head,
         /* index= */ NULL,
-        /* opts = */ NULL);
+        opts);
     if (error)
 	goto cleanup;
 
@@ -267,7 +411,7 @@ SEXP git2r_diff_head_to_index(SEXP repo, SEXP filename)
             nprotect++;
         }
 
-        git_buf_free(&buf);
+        GIT2R_BUF_DISPOSE(&buf);
     } else {
         FILE *fp = fopen(CHAR(STRING_ELT(filename, 0)), "w+");
 
@@ -282,6 +426,7 @@ SEXP git2r_diff_head_to_index(SEXP repo, SEXP filename)
     }
 
 cleanup:
+    free(opts->pathspec.strings);
     git_tree_free(head);
     git_object_free(obj);
     git_diff_free(diff);
@@ -291,7 +436,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return result;
 }
@@ -306,10 +451,16 @@ cleanup:
  * diff is written to a character vector. If filename is a character
  * vector of length one with non-NA value, the diff is written to a
  * file with name filename (the file is overwritten if it exists).
+ * @param opts Structure describing options about how the diff
+ * should be executed.
  * @return A S3 class git_diff object if filename equals R_NilValue. A
  * character vector with diff if filename has length 0. Oterwise NULL.
  */
-SEXP git2r_diff_tree_to_wd(SEXP tree, SEXP filename)
+SEXP attribute_hidden
+git2r_diff_tree_to_wd(
+    SEXP tree,
+    SEXP filename,
+    git_diff_options *opts)
 {
     int error, nprotect = 0;
     git_repository *repository = NULL;
@@ -339,7 +490,7 @@ SEXP git2r_diff_tree_to_wd(SEXP tree, SEXP filename)
     if (error)
 	goto cleanup;
 
-    error = git_diff_tree_to_workdir(&diff, repository, c_tree, /* opts = */ NULL);
+    error = git_diff_tree_to_workdir(&diff, repository, c_tree, opts);
     if (error)
 	goto cleanup;
 
@@ -372,7 +523,7 @@ SEXP git2r_diff_tree_to_wd(SEXP tree, SEXP filename)
             nprotect++;
         }
 
-        git_buf_free(&buf);
+        GIT2R_BUF_DISPOSE(&buf);
     } else {
         FILE *fp = fopen(CHAR(STRING_ELT(filename, 0)), "w+");
 
@@ -387,6 +538,7 @@ SEXP git2r_diff_tree_to_wd(SEXP tree, SEXP filename)
     }
 
 cleanup:
+    free(opts->pathspec.strings);
     git_diff_free(diff);
     git_tree_free(c_tree);
     git_object_free(obj);
@@ -396,7 +548,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return result;
 }
@@ -411,10 +563,16 @@ cleanup:
  * diff is written to a character vector. If filename is a character
  * vector of length one with non-NA value, the diff is written to a
  * file with name filename (the file is overwritten if it exists).
+ * @param opts Structure describing options about how the diff
+ * should be executed.
  * @return A S3 class git_diff object if filename equals R_NilValue. A
  * character vector with diff if filename has length 0. Oterwise NULL.
  */
-SEXP git2r_diff_tree_to_index(SEXP tree, SEXP filename)
+SEXP attribute_hidden
+git2r_diff_tree_to_index(
+    SEXP tree,
+    SEXP filename,
+    git_diff_options *opts)
 {
     int error, nprotect = 0;
     git_repository *repository = NULL;
@@ -449,7 +607,7 @@ SEXP git2r_diff_tree_to_index(SEXP tree, SEXP filename)
         repository,
         c_tree,
         /* index= */ NULL,
-        /* opts= */ NULL);
+        opts);
     if (error)
 	goto cleanup;
 
@@ -482,7 +640,7 @@ SEXP git2r_diff_tree_to_index(SEXP tree, SEXP filename)
             nprotect++;
         }
 
-        git_buf_free(&buf);
+        GIT2R_BUF_DISPOSE(&buf);
     } else {
         FILE *fp = fopen(CHAR(STRING_ELT(filename, 0)), "w+");
 
@@ -497,6 +655,7 @@ SEXP git2r_diff_tree_to_index(SEXP tree, SEXP filename)
     }
 
 cleanup:
+    free(opts->pathspec.strings);
     git_diff_free(diff);
     git_tree_free(c_tree);
     git_object_free(obj);
@@ -506,7 +665,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-	git2r_error(__func__, giterr_last(), NULL, NULL);
+	git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return result;
 }
@@ -522,10 +681,17 @@ cleanup:
  * diff is written to a character vector. If filename is a character
  * vector of length one with non-NA value, the diff is written to a
  * file with name filename (the file is overwritten if it exists).
+ * @param opts Structure describing options about how the diff
+ * should be executed.
  * @return A S3 class git_diff object if filename equals R_NilValue. A
  * character vector with diff if filename has length 0. Oterwise NULL.
  */
-SEXP git2r_diff_tree_to_tree(SEXP tree1, SEXP tree2, SEXP filename)
+SEXP attribute_hidden
+git2r_diff_tree_to_tree(
+    SEXP tree1,
+    SEXP tree2,
+    SEXP filename,
+    git_diff_options *opts)
 {
     int error, nprotect = 0;
     git_repository *repository = NULL;
@@ -575,7 +741,7 @@ SEXP git2r_diff_tree_to_tree(SEXP tree1, SEXP tree2, SEXP filename)
         repository,
         c_tree1,
         c_tree2,
-        /* opts= */ NULL);
+        opts);
     if (error)
 	goto cleanup;
 
@@ -608,7 +774,7 @@ SEXP git2r_diff_tree_to_tree(SEXP tree1, SEXP tree2, SEXP filename)
             nprotect++;
         }
 
-        git_buf_free(&buf);
+        GIT2R_BUF_DISPOSE(&buf);
     } else {
         FILE *fp = fopen(CHAR(STRING_ELT(filename, 0)), "w+");
 
@@ -623,6 +789,7 @@ SEXP git2r_diff_tree_to_tree(SEXP tree1, SEXP tree2, SEXP filename)
     }
 
 cleanup:
+    free(opts->pathspec.strings);
     git_diff_free(diff);
     git_tree_free(c_tree1);
     git_tree_free(c_tree2);
@@ -634,7 +801,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-	git2r_error(__func__, giterr_last(), NULL, NULL);
+	git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return result;
 }
@@ -658,12 +825,17 @@ typedef struct {
  * @param payload A pointer to the git2r_diff_count_payload data structure
  * @return 0
  */
-int git2r_diff_count_file_cb(const git_diff_delta *delta,
-			     float progress,
-			     void *payload)
+static int
+git2r_diff_count_file_cb(
+    const git_diff_delta *delta,
+    float progress,
+    void *payload)
 {
     git2r_diff_count_payload *n = payload;
 
+    GIT2R_UNUSED(delta);
+    GIT2R_UNUSED(progress);
+
     n->num_files += 1;
     n->num_hunks = n->num_lines = 0;
     return 0;
@@ -677,12 +849,17 @@ int git2r_diff_count_file_cb(const git_diff_delta *delta,
  * @param payload A pointer to the git2r_diff_count_payload data structure
  * @return 0
  */
-int git2r_diff_count_hunk_cb(const git_diff_delta *delta,
-			     const git_diff_hunk *hunk,
-			     void *payload)
+static int
+git2r_diff_count_hunk_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    void *payload)
 {
     git2r_diff_count_payload *n = payload;
 
+    GIT2R_UNUSED(delta);
+    GIT2R_UNUSED(hunk);
+
     n->num_hunks += 1;
     if (n->num_hunks > n->max_hunks) { n->max_hunks = n->num_hunks; }
     n->num_lines = 0;
@@ -699,13 +876,19 @@ int git2r_diff_count_hunk_cb(const git_diff_delta *delta,
  * @param payload A pointer to the git2r_diff_count_payload data structure
  * @return 0
  */
-int git2r_diff_count_line_cb(const git_diff_delta *delta,
-			     const git_diff_hunk *hunk,
-			     const git_diff_line *line,
-			     void *payload)
+static int
+git2r_diff_count_line_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    const git_diff_line *line,
+    void *payload)
 {
     git2r_diff_count_payload *n = payload;
 
+    GIT2R_UNUSED(delta);
+    GIT2R_UNUSED(hunk);
+    GIT2R_UNUSED(line);
+
     n->num_lines += 1;
     if (n->num_lines > n->max_lines)
         n->max_lines = n->num_lines;
@@ -722,10 +905,12 @@ int git2r_diff_count_line_cb(const git_diff_delta *delta,
  * @param max_lines Pointer where to save the maximum number of lines
  * @return 0 if OK, else -1
  */
-int git2r_diff_count(git_diff *diff,
-                     size_t *num_files,
-		     size_t *max_hunks,
-                     size_t *max_lines)
+static int
+git2r_diff_count(
+    git_diff *diff,
+    size_t *num_files,
+    size_t *max_hunks,
+    size_t *max_lines)
 {
     int error;
     git2r_diff_count_payload n = { 0, 0, 0 };
@@ -758,14 +943,18 @@ typedef struct {
     size_t file_ptr, hunk_ptr, line_ptr;
 } git2r_diff_payload;
 
-int git2r_diff_get_hunk_cb(const git_diff_delta *delta,
-			   const git_diff_hunk *hunk,
-			   void *payload);
+static int
+git2r_diff_get_hunk_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    void *payload);
 
-int git2r_diff_get_line_cb(const git_diff_delta *delta,
-			   const git_diff_hunk *hunk,
-			   const git_diff_line *line,
-			   void *payload);
+static int
+git2r_diff_get_line_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    const git_diff_line *line,
+    void *payload);
 
 /**
  * Callback per file in the diff
@@ -775,12 +964,16 @@ int git2r_diff_get_line_cb(const git_diff_delta *delta,
  * @param payload A pointer to the git2r_diff_payload data structure
  * @return 0
  */
-int git2r_diff_get_file_cb(const git_diff_delta *delta,
-			   float progress,
-			   void *payload)
+static int
+git2r_diff_get_file_cb(
+    const git_diff_delta *delta,
+    float progress,
+    void *payload)
 {
     git2r_diff_payload *p = (git2r_diff_payload *) payload;
 
+    GIT2R_UNUSED(progress);
+
     /* Save previous hunk's lines in hunk_tmp, we just call the
        hunk callback, with a NULL hunk */
     git2r_diff_get_hunk_cb(delta, /* hunk= */ 0, payload);
@@ -809,7 +1002,6 @@ int git2r_diff_get_file_cb(const git_diff_delta *delta,
             R_ClassSymbol,
             Rf_mkString(git2r_S3_class__git_diff_file));
         SET_VECTOR_ELT(p->result, p->file_ptr, file_obj);
-        UNPROTECT(1);
 
 	SET_VECTOR_ELT(
             file_obj,
@@ -824,6 +1016,7 @@ int git2r_diff_get_file_cb(const git_diff_delta *delta,
 	p->file_ptr++;
 	p->hunk_ptr = 0;
 	p->line_ptr = 0;
+        UNPROTECT(1);
     }
 
     return 0;
@@ -840,12 +1033,16 @@ int git2r_diff_get_file_cb(const git_diff_delta *delta,
  * @param payload Pointer to a git2r_diff_payload data structure
  * @return 0
  */
-int git2r_diff_get_hunk_cb(const git_diff_delta *delta,
-			   const git_diff_hunk *hunk,
-			   void *payload)
+static int
+git2r_diff_get_hunk_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    void *payload)
 {
     git2r_diff_payload *p = (git2r_diff_payload *) payload;
 
+    GIT2R_UNUSED(delta);
+
     /* Save previous hunk's lines in hunk_tmp, from the line_tmp
        temporary storage. */
     if (p->hunk_ptr != 0) {
@@ -917,16 +1114,21 @@ int git2r_diff_get_hunk_cb(const git_diff_delta *delta,
  * @param payload Pointer to a git2r_diff_payload data structure
  * @return 0
  */
-int git2r_diff_get_line_cb(const git_diff_delta *delta,
-			   const git_diff_hunk *hunk,
-			   const git_diff_line *line,
-			   void *payload)
+static int
+git2r_diff_get_line_cb(
+    const git_diff_delta *delta,
+    const git_diff_hunk *hunk,
+    const git_diff_line *line,
+    void *payload)
 {
     git2r_diff_payload *p = (git2r_diff_payload *) payload;
     static char short_buffer[200];
     char *buffer = short_buffer;
     SEXP line_obj;
 
+    GIT2R_UNUSED(delta);
+    GIT2R_UNUSED(hunk);
+
     PROTECT(line_obj = Rf_mkNamed(VECSXP, git2r_S3_items__git_diff_line));
     Rf_setAttrib(
         line_obj,
@@ -990,7 +1192,10 @@ int git2r_diff_get_line_cb(const git_diff_delta *delta,
  * @param dest The S3 class git_diff to hold the formated diff
  * @return 0 if OK, else error code
  */
-int git2r_diff_format_to_r(git_diff *diff, SEXP dest)
+static int
+git2r_diff_format_to_r(
+    git_diff *diff,
+    SEXP dest)
 {
     int error, nprotect = 0;
     git2r_diff_payload payload = { /* result=   */ R_NilValue,
