@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2018 The git2r contributors
+ *  Copyright (C) 2013-2020 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,11 +16,13 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
 #include "git2r_blob.h"
 #include "git2r_commit.h"
+#include "git2r_deprecated.h"
 #include "git2r_error.h"
 #include "git2r_repository.h"
 #include "git2r_S3.h"
@@ -35,7 +37,10 @@
  * http://git-scm.com/docs/git-rev-parse.html#_specifying_revisions
  * @return S3 object of class git_commit, git_tag or git_tree.
  */
-SEXP git2r_revparse_single(SEXP repo, SEXP revision)
+SEXP attribute_hidden
+git2r_revparse_single(
+    SEXP repo,
+    SEXP revision)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -57,28 +62,28 @@ SEXP git2r_revparse_single(SEXP repo, SEXP revision)
         goto cleanup;
 
     switch (git_object_type(treeish)) {
-    case GIT_OBJ_BLOB:
+    case GIT2R_OBJECT_BLOB:
         PROTECT(result = Rf_mkNamed(VECSXP, git2r_S3_items__git_blob));
         nprotect++;
         Rf_setAttrib(result, R_ClassSymbol,
                      Rf_mkString(git2r_S3_class__git_blob));
         git2r_blob_init((git_blob*)treeish, repo, result);
         break;
-    case GIT_OBJ_COMMIT:
+    case GIT2R_OBJECT_COMMIT:
         PROTECT(result = Rf_mkNamed(VECSXP, git2r_S3_items__git_commit));
         nprotect++;
         Rf_setAttrib(result, R_ClassSymbol,
                      Rf_mkString(git2r_S3_class__git_commit));
         git2r_commit_init((git_commit*)treeish, repo, result);
         break;
-    case GIT_OBJ_TAG:
+    case GIT2R_OBJECT_TAG:
         PROTECT(result = Rf_mkNamed(VECSXP, git2r_S3_items__git_tag));
         nprotect++;
         Rf_setAttrib(result, R_ClassSymbol,
                      Rf_mkString(git2r_S3_class__git_tag));
         git2r_tag_init((git_tag*)treeish, repo, result);
         break;
-    case GIT_OBJ_TREE:
+    case GIT2R_OBJECT_TREE:
         PROTECT(result = Rf_mkNamed(VECSXP, git2r_S3_items__git_tree));
         nprotect++;
         Rf_setAttrib(result, R_ClassSymbol,
@@ -86,7 +91,7 @@ SEXP git2r_revparse_single(SEXP repo, SEXP revision)
         git2r_tree_init((git_tree*)treeish, repo, result);
         break;
     default:
-        giterr_set_str(GITERR_NONE, git2r_err_revparse_single);
+        GIT2R_ERROR_SET_STR(GIT2R_ERROR_NONE, git2r_err_revparse_single);
         error = GIT_ERROR;
         break;
     }
@@ -108,7 +113,7 @@ cleanup:
         } else {
             git2r_error(
                 __func__,
-                giterr_last(),
+                GIT2R_ERROR_LAST(),
                 NULL,
                 NULL);
         }
