@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2018 The git2r contributors
+ *  Copyright (C) 2013-2020 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,10 +16,12 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
 #include "git2r_commit.h"
+#include "git2r_deprecated.h"
 #include "git2r_error.h"
 #include "git2r_repository.h"
 #include "git2r_S3.h"
@@ -44,7 +46,10 @@ typedef struct {
  * @param index The index to the stash. 0 is the most recent stash.
  * @return R_NilValue
  */
-SEXP git2r_stash_apply(SEXP repo, SEXP index)
+SEXP attribute_hidden
+git2r_stash_apply(
+    SEXP repo,
+    SEXP index)
 {
     int error;
     git_repository *repository = NULL;
@@ -61,7 +66,7 @@ SEXP git2r_stash_apply(SEXP repo, SEXP index)
         error = 0;
     git_repository_free(repository);
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return R_NilValue;
 }
@@ -73,7 +78,10 @@ SEXP git2r_stash_apply(SEXP repo, SEXP index)
  * @param index The index to the stash. 0 is the most recent stash.
  * @return R_NilValue
  */
-SEXP git2r_stash_drop(SEXP repo, SEXP index)
+SEXP attribute_hidden
+git2r_stash_drop(
+    SEXP repo,
+    SEXP index)
 {
     int error;
     git_repository *repository = NULL;
@@ -88,7 +96,7 @@ SEXP git2r_stash_drop(SEXP repo, SEXP index)
     error = git_stash_drop(repository, INTEGER(index)[0]);
     git_repository_free(repository);
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return R_NilValue;
 }
@@ -101,7 +109,10 @@ SEXP git2r_stash_drop(SEXP repo, SEXP index)
  * @param index The index to the stash. 0 is the most recent stash.
  * @return R_NilValue
  */
-SEXP git2r_stash_pop(SEXP repo, SEXP index)
+SEXP attribute_hidden
+git2r_stash_pop(
+    SEXP repo,
+    SEXP index)
 {
     int error;
     git_repository *repository = NULL;
@@ -118,7 +129,7 @@ SEXP git2r_stash_pop(SEXP repo, SEXP index)
         error = 0;
     git_repository_free(repository);
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return R_NilValue;
 }
@@ -132,7 +143,8 @@ SEXP git2r_stash_pop(SEXP repo, SEXP index)
  * @param dest S3 class git_stash to initialize
  * @return int 0 on success, or an error code.
  */
-int git2r_stash_init(
+static int
+git2r_stash_init(
     const git_oid *source,
     git_repository *repository,
     SEXP repo,
@@ -160,24 +172,29 @@ int git2r_stash_init(
  * @param payload Pointer to a git2r_stash_list_cb_data data structure.
  * @return 0 if OK, else error code
  */
-static int git2r_stash_list_cb(
+static int
+git2r_stash_list_cb(
     size_t index,
     const char* message,
     const git_oid *stash_id,
     void *payload)
 {
+    int error = 0, nprotect = 0;
+    SEXP stash, class;
     git2r_stash_list_cb_data *cb_data = (git2r_stash_list_cb_data*)payload;
 
+    GIT2R_UNUSED(index);
+    GIT2R_UNUSED(message);
+
     /* Check if we have a list to populate */
     if (!Rf_isNull(cb_data->list)) {
-        int error;
-        SEXP stash, class;
-
         PROTECT(class = Rf_allocVector(STRSXP, 2));
+        nprotect++;
         SET_STRING_ELT(class, 0, Rf_mkChar("git_stash"));
         SET_STRING_ELT(class, 1, Rf_mkChar("git_commit"));
 
         PROTECT(stash = Rf_mkNamed(VECSXP, git2r_S3_items__git_commit));
+        nprotect++;
         Rf_setAttrib(stash, R_ClassSymbol, class);
 
         error = git2r_stash_init(
@@ -186,15 +203,18 @@ static int git2r_stash_list_cb(
             cb_data->repo,
             stash);
         if (error)
-            return error;
+            goto cleanup;
 
         SET_VECTOR_ELT(cb_data->list, cb_data->n, stash);
-        UNPROTECT(2);
     }
 
     cb_data->n += 1;
 
-    return 0;
+cleanup:
+    if (nprotect)
+        UNPROTECT(nprotect);
+
+    return error;
 }
 
 /**
@@ -203,7 +223,9 @@ static int git2r_stash_list_cb(
  * @param repo S3 class git_repository
  * @return VECXSP with S3 objects of class git_stash
  */
-SEXP git2r_stash_list(SEXP repo)
+SEXP attribute_hidden
+git2r_stash_list(
+    SEXP repo)
 {
     SEXP list = R_NilValue;
     int error, nprotect = 0;
@@ -234,7 +256,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return list;
 }
@@ -253,7 +275,8 @@ cleanup:
  * @param stasher Signature with stasher and time of stash
  * @return S3 class git_stash
  */
-SEXP git2r_stash_save(
+SEXP attribute_hidden
+git2r_stash_save(
     SEXP repo,
     SEXP message,
     SEXP index,
@@ -321,7 +344,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, GIT2R_ERROR_LAST(), NULL, NULL);
 
     return result;
 }
