@@ -20,15 +20,21 @@ library("git2r")
 sessionInfo()
 
 ## Check when method
-w1 = structure(list(time = 1395567947, offset = 60),
+w1 <- structure(list(time = 1395567947, offset = 60),
                class = "git_time")
-stopifnot(identical(when(w1), "2014-03-23 09:45:47"))
+stopifnot(identical(when(w1), "2014-03-23 09:45:47 GMT"))
+stopifnot(identical(when(w1, usetz = FALSE), "2014-03-23 09:45:47"))
+stopifnot(identical(when(w1, tz = "Europe/Stockholm", origin = "1980-02-02"),
+                    "2024-04-23 11:45:47 CEST"))
 
 s1 <- structure(list(name = "Alice", email = "alice@example.org", when = w1),
                 class = "git_signature")
-stopifnot(identical(when(s1), "2014-03-23 09:45:47"))
+stopifnot(identical(when(s1), "2014-03-23 09:45:47 GMT"))
+stopifnot(identical(when(s1, usetz = FALSE), "2014-03-23 09:45:47"))
+stopifnot(identical(when(s1, tz = "Europe/Stockholm", origin = "1980-02-02"),
+                    "2024-04-23 11:45:47 CEST"))
 
-w2 = structure(list(time = 1395567950, offset = 60),
+w2 <- structure(list(time = 1395567950, offset = 60),
                class = "git_time")
 s2 <- structure(list(name = "Alice", email = "alice@example.org", when = w2),
                 class = "git_signature")
@@ -38,7 +44,10 @@ c1 <- structure(list(sha = "166f3f779fd7e4165aaa43f2828050ce040052b0",
                      summary = "A commit summary",
                      message = "A commit message"),
                 class = "git_commit")
-stopifnot(identical(when(c1), "2014-03-23 09:45:47"))
+stopifnot(identical(when(c1), "2014-03-23 09:45:47 GMT"))
+stopifnot(identical(when(c1, usetz = FALSE), "2014-03-23 09:45:47"))
+stopifnot(identical(when(c1, tz = "Europe/Stockholm", origin = "1980-02-02"),
+                    "2024-04-23 11:45:47 CEST"))
 
 t1 <- structure(list(sha = "166f3f779fd7e4165aaa43f2828050ce040052b0",
                      message = "A tag message",
@@ -46,4 +55,7 @@ t1 <- structure(list(sha = "166f3f779fd7e4165aaa43f2828050ce040052b0",
                      tagger = s1,
                      target = "166f3f779fd7e4165aaa43f2828050ce040052b0"),
                 class = "git_tag")
-stopifnot(identical(when(t1), "2014-03-23 09:45:47"))
+stopifnot(identical(when(t1), "2014-03-23 09:45:47 GMT"))
+stopifnot(identical(when(t1, usetz = FALSE), "2014-03-23 09:45:47"))
+stopifnot(identical(when(t1, tz = "Europe/Stockholm", origin = "1980-02-02"),
+                    "2024-04-23 11:45:47 CEST"))
